define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "овог квартала",
	"field-quarter-short-relative+1": "следећег квартала",
	"field-tue-relative+-1": "прошлог уторка",
	"field-year": "година",
	"field-wed-relative+0": "у среду",
	"field-wed-relative+1": "следеће среде",
	"field-minute": "минут",
	"field-month-narrow-relative+-1": "прошлог м.",
	"field-tue-narrow-relative+0": "у уто",
	"field-tue-narrow-relative+1": "следећег уто",
	"field-thu-short-relative+0": "у чет",
	"field-day-short-relative+-1": "јуче",
	"field-thu-short-relative+1": "следећег чет",
	"field-day-relative+0": "данас",
	"field-day-short-relative+-2": "прекјуче",
	"field-day-relative+1": "сутра",
	"field-week-narrow-relative+0": "ове н.",
	"field-day-relative+2": "прекосутра",
	"field-week-narrow-relative+1": "следеће н.",
	"field-wed-narrow-relative+-1": "прошле сре",
	"field-year-narrow": "г.",
	"field-era-short": "ера",
	"field-year-narrow-relative+0": "ове г.",
	"field-tue-relative+0": "у уторак",
	"field-year-narrow-relative+1": "следеће г.",
	"field-tue-relative+1": "следећег уторка",
	"field-weekdayOfMonth": "дан у месецу",
	"field-second-short": "сек.",
	"field-weekdayOfMonth-narrow": "дан у месецу",
	"field-week-relative+0": "ове недеље",
	"field-month-relative+0": "овог месеца",
	"field-week-relative+1": "следеће недеље",
	"field-month-relative+1": "следећег месеца",
	"field-sun-narrow-relative+0": "у нед",
	"field-mon-short-relative+0": "у пон",
	"field-sun-narrow-relative+1": "сл. нед.",
	"field-mon-short-relative+1": "следећег пон",
	"field-second-relative+0": "сада",
	"field-weekOfMonth": "недеља у месецу",
	"field-month-short": "мес.",
	"field-day": "дан",
	"field-dayOfYear-short": "дан у год.",
	"field-year-relative+-1": "прошле године",
	"field-sat-short-relative+-1": "прошле суб",
	"field-hour-relative+0": "овог сата",
	"field-wed-relative+-1": "прошле среде",
	"field-sat-narrow-relative+-1": "прошле суб",
	"field-second": "секунд",
	"field-quarter": "квартал",
	"field-week-short": "нед.",
	"field-day-narrow-relative+0": "данас",
	"field-day-narrow-relative+1": "сутра",
	"field-day-narrow-relative+2": "прекосутра",
	"field-tue-short-relative+0": "у уто",
	"field-tue-short-relative+1": "следећег уто",
	"field-month-short-relative+-1": "прошлог мес.",
	"field-mon-relative+-1": "прошлог понедељка",
	"field-month": "месец",
	"field-day-narrow": "д.",
	"field-minute-short": "мин.",
	"field-dayperiod": "пре подне/по подне",
	"field-sat-short-relative+0": "у суб",
	"field-sat-short-relative+1": "следеће суб",
	"eraAbbr": [
		"Пре РК",
		"РК"
	],
	"field-second-narrow": "с.",
	"field-mon-relative+0": "у понедељак",
	"field-mon-relative+1": "следећег понедељка",
	"field-day-narrow-relative+-1": "јуче",
	"field-year-short": "год.",
	"field-day-narrow-relative+-2": "прекјуче",
	"field-quarter-relative+-1": "прошлог квартала",
	"field-dayperiod-narrow": "пре подне/по подне",
	"field-week-narrow-relative+-1": "прошле н.",
	"field-dayOfYear": "дан у години",
	"field-sat-relative+-1": "прошле суботе",
	"field-hour": "сат",
	"field-month-relative+-1": "прошлог месеца",
	"field-quarter-short": "кв.",
	"field-sat-narrow-relative+0": "у суб",
	"field-fri-relative+0": "у петак",
	"field-sat-narrow-relative+1": "следеће суб",
	"field-fri-relative+1": "следећег петка",
	"field-month-narrow-relative+0": "овог м.",
	"field-month-narrow-relative+1": "следећег м.",
	"field-sun-short-relative+0": "у нед",
	"field-sun-short-relative+1": "сл. нед.",
	"field-week-relative+-1": "прошле недеље",
	"field-quarter-short-relative+-1": "прошлог квартала",
	"field-quarter-relative+0": "овог квартала",
	"field-minute-relative+0": "овог минута",
	"field-quarter-relative+1": "следећег квартала",
	"field-wed-short-relative+-1": "прошле сре",
	"field-thu-short-relative+-1": "прошлог чет",
	"field-year-narrow-relative+-1": "прошле г.",
	"field-mon-narrow-relative+-1": "прошлог пон",
	"field-thu-narrow-relative+-1": "прошлог чет",
	"field-tue-narrow-relative+-1": "прошлог уто",
	"field-weekOfMonth-short": "нед. у мес.",
	"field-wed-short-relative+0": "у сре",
	"field-wed-short-relative+1": "следеће сре",
	"field-sun-relative+-1": "прошле недеље",
	"field-weekday": "дан у недељи",
	"field-day-short-relative+0": "данас",
	"field-quarter-narrow-relative+0": "овог квартала",
	"field-sat-relative+0": "у суботу",
	"field-day-short-relative+1": "сутра",
	"field-quarter-narrow-relative+1": "следећег квартала",
	"field-sat-relative+1": "следеће суботе",
	"field-day-short-relative+2": "прекосутра",
	"field-week-short-relative+0": "ове нед.",
	"field-week-short-relative+1": "следеће нед.",
	"field-dayOfYear-narrow": "дан у год.",
	"field-month-short-relative+0": "овог мес.",
	"field-month-short-relative+1": "следећег мес.",
	"field-weekdayOfMonth-short": "дан у месецу",
	"field-zone-narrow": "временска зона",
	"field-thu-narrow-relative+0": "у чет",
	"field-thu-narrow-relative+1": "следећег чет",
	"field-sun-narrow-relative+-1": "пр. нед.",
	"field-mon-short-relative+-1": "прошлог пон",
	"field-thu-relative+0": "у четвртак",
	"field-thu-relative+1": "следећег четвртка",
	"field-fri-short-relative+-1": "прошлог пет",
	"field-thu-relative+-1": "прошлог четвртка",
	"field-week": "недеља",
	"field-wed-narrow-relative+0": "у сре",
	"field-wed-narrow-relative+1": "следеће сре",
	"field-quarter-narrow-relative+-1": "прошлог квартала",
	"field-year-short-relative+0": "ове год.",
	"field-dayperiod-short": "пре подне/по подне",
	"field-year-short-relative+1": "следеће год.",
	"field-fri-short-relative+0": "у пет",
	"field-fri-short-relative+1": "следећег пет",
	"field-week-short-relative+-1": "прошле нед.",
	"field-hour-short": "ч.",
	"field-zone-short": "временска зона",
	"field-month-narrow": "м.",
	"field-hour-narrow": "ч.",
	"field-fri-narrow-relative+-1": "прошлог пет",
	"field-year-relative+0": "ове године",
	"field-year-relative+1": "следеће године",
	"field-era-narrow": "ера",
	"field-fri-relative+-1": "прошлог петка",
	"field-tue-short-relative+-1": "прошлог уто",
	"field-minute-narrow": "мин.",
	"field-mon-narrow-relative+0": "у пон",
	"field-mon-narrow-relative+1": "следећег пон",
	"field-year-short-relative+-1": "прошле год.",
	"field-zone": "временска зона",
	"field-weekOfMonth-narrow": "нед. у мес.",
	"field-weekday-narrow": "дан у недељи",
	"field-quarter-narrow": "кв.",
	"field-sun-short-relative+-1": "пр. нед.",
	"field-day-relative+-1": "јуче",
	"field-day-relative+-2": "прекјуче",
	"field-weekday-short": "дан у недељи",
	"field-sun-relative+0": "у недељу",
	"field-sun-relative+1": "следеће недеље",
	"field-day-short": "д.",
	"field-week-narrow": "н.",
	"field-era": "ера",
	"field-fri-narrow-relative+0": "у пет",
	"field-fri-narrow-relative+1": "следећег пет"
}
//end v1.x content
);